==> nextcloud-app-spreed-1%3A9.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/id.js <==
OC.L10N.register(
    "spreed",
    {
    "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
    "Limit to groups" : "Batasi ke grup",
    "Everyone" : "Semua orang",
    "Save changes" : "Simpan perubahan",
    "Saving …" : "Menyimpan ...",
    "None" : "Tidak ada",
    "User" : "Pengguna",
    "Disabled" : "Dinonaktifkan",
    "Users" : "Pengguna",
    "Name" : "Nama",
    "Saved" : "Disimpan",
    "Copy link" : "Salin tautan",
    "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Tambah ke favorit",
    "Loading" : "Memuat",
    "Groups" : "Grup",
    "Invalid path selected" : "Jalur terpilih invalid",
    "Error" : "Kesalahan",
    "Password protect" : "Lindungi dengan kata sandi",
    "Back" : "Kembali",
    "Close" : "Tutup",
    "Reply" : "Balas",
    "Today" : "Hari ini",
    "Yesterday" : "Kemarin",
    "guest" : "pengunjung",
    "No results" : "Tidak ada hasil",
    "Add users or groups" : "Add users or groups",
    "Settings" : "Setelan",
    "Edit" : "Sunting",
    "Dismiss" : "Batal",
    "Share link" : "Bagikan tautan",
    "Password protection" : "Password protection",
    "Enter a password" : "Masukkan kata sandi",
    "Grid view" : "Tampilan kotak",
    "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
    "Password" : "Kata kunci",
    "Android app" : "Aplikasi Android",
    "iOS app" : "Aplikasi iOS",
    "Copy" : "Salin",
    "Copied!" : "Tersalin!",
    "Not supported!" : "Tidak didukung!",
    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
    "Press Ctrl-C to copy." : "Tekan CTRL-C untuk menyalin.",
    "Password required" : "Kata sandi diperlukan",
    "Cancel" : "Membatalkan",
    "Change password" : "Ubah kata sandi",
    "Set password" : "Atur kata sandi",
    "Rename" : "Ubah nama",
    "Send" : "Kirim",
    "Share" : "Bagikan",
    "Error while sharing" : "Kesalahan saat membagikan",
    "Favorited" : "Difavoritkan",
    "Contacts" : "Kontak"
},
"nplurals=1; plural=0;");

==> nextcloud-app-spreed-1%3A9.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/id.js <==
OC.L10N.register(
    "spreed",
    {
    "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
    "Limit to groups" : "Batasi ke grup",
    "Everyone" : "Semua orang",
    "Save changes" : "Simpan perubahan",
    "Saving …" : "Menyimpan ...",
    "None" : "Tidak ada",
    "User" : "Pengguna",
    "Disabled" : "Dinonaktifkan",
    "Users" : "Pengguna",
    "Name" : "Nama",
    "Language" : "Bahasa",
    "Country" : "Negara",
    "Status" : "Status",
    "Created at" : "Dibuat saat",
    "Pending" : "Tunggu",
    "Error" : "Kesalahan",
    "Saved" : "Disimpan",
    "Copy link" : "Salin tautan",
    "Dismiss" : "Batal",
    "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Tambah ke favorit",
    "Loading" : "Memuat",
    "Groups" : "Grup",
    "Invalid path selected" : "Jalur terpilih invalid",
    "Password protect" : "Lindungi dengan kata sandi",
    "Back" : "Kembali",
    "Close" : "Tutup",
    "Reply" : "Balas",
    "Today" : "Hari ini",
    "Yesterday" : "Kemarin",
    "guest" : "pengunjung",
    "No results" : "Tidak ada hasil",
    "Add users or groups" : "Add users or groups",
    "Projects" : "Proyek",
    "Settings" : "Setelan",
    "Edit" : "Sunting",
    "Share link" : "Bagikan tautan",
    "Password protection" : "Password protection",
    "Enter a password" : "Masukkan kata sandi",
    "Grid view" : "Tampilan kotak",
    "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
    "Password" : "Kata kunci",
    "Android app" : "Aplikasi Android",
    "iOS app" : "Aplikasi iOS",
    "Copy" : "Salin",
    "Copied!" : "Tersalin!",
    "Not supported!" : "Tidak didukung!",
    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
    "Press Ctrl-C to copy." : "Tekan CTRL-C untuk menyalin.",
    "Password required" : "Kata sandi diperlukan",
    "Cancel" : "Membatalkan",
    "Change password" : "Ubah kata sandi",
    "Set password" : "Atur kata sandi",
    "Rename" : "Ubah nama",
    "Send" : "Kirim",
    "Share" : "Bagikan",
    "Error while sharing" : "Kesalahan saat membagikan",
    "Favorited" : "Difavoritkan",
    "Contacts" : "Kontak"
},
"nplurals=1; plural=0;");
